package be.iminds.ilabt.jfed.experimenter_gui.events;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.io.File;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Objects;

/**
 * User: twalcari
 * Date: 6/25/2015
 * Time: 17:43
 */
public class OpenESpecEvent {
    public enum ESpecSource { DIR, URL, ARCHIVE, GIT }

    @Nonnull private final ESpecSource eSpecSource;
    @Nullable private final File file;
    @Nullable private final URL url;
    @Nullable private final String gitSpec;

    public OpenESpecEvent(@Nonnull URL url) {
        this.file = null;
        this.eSpecSource = ESpecSource.URL;
        this.url = url;
        this.gitSpec = null;
    }

    public OpenESpecEvent(@Nonnull File file) {
        this.file = file;
        this.eSpecSource = file.isDirectory() ? ESpecSource.DIR : ESpecSource.ARCHIVE;
        this.url = null;
        this.gitSpec = null;
    }

    public OpenESpecEvent(@Nonnull String any) throws MalformedURLException {
        if (any.startsWith("http")) {
            this.file = null;
            this.eSpecSource = ESpecSource.URL;
            this.url = new URL(any);
            this.gitSpec = null;
        } else {
            if (any.startsWith("git ")|| any.startsWith("github ")) {
                this.file = null;
                this.eSpecSource = ESpecSource.GIT;
                this.url = null;
                this.gitSpec = any;
            } else {
                this.file = new File(any);
                this.eSpecSource = file.isDirectory() ? ESpecSource.DIR : ESpecSource.ARCHIVE;
                this.url = null;
                this.gitSpec = null;
            }
        }
    }

    @Nonnull
    public ESpecSource getESpecSource() {
        return eSpecSource;
    }

    @Nullable
    public File getFile() {
        return file;
    }

    @Nullable
    public URL getUrl() {
        return url;
    }

    @Nullable
    public String getGitSpec() {
        return gitSpec;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof OpenESpecEvent)) return false;
        OpenESpecEvent that = (OpenESpecEvent) o;
        return eSpecSource == that.eSpecSource &&
                Objects.equals(file, that.file) &&
                Objects.equals(url, that.url) &&
                Objects.equals(gitSpec, that.gitSpec);
    }

    @Override
    public int hashCode() {

        return Objects.hash(eSpecSource, file, url, gitSpec);
    }

    @Override
    public String toString() {
        return "OpenESpecEvent{" +
                "eSpecSource=" + eSpecSource +
                ", file=" + file +
                ", url=" + url +
                ", gitSpec='" + gitSpec + '\'' +
                '}';
    }
}
